@@ -19,6 +19,10 @@ const (
 	// deprovisioned.
 	BareMetalHostFinalizer string = "baremetalhost.metal3.io"
 
+	// PausedAnnotation is the annotation that pauses the reconciliation (triggers
+	// an immediate requeue)
+	PausedAnnotation = "baremetalhost.metal3.io/paused"
+
 	// StatusAnnotation is the annotation that holds the Status of BMH
 	StatusAnnotation = "baremetalhost.metal3.io/status"
 )
@@ -83,6 +87,9 @@ const (
 	// StateReady means the host can be consumed
 	StateReady ProvisioningState = "ready"
 
+	// StateAvailable means the host can be consumed
+	StateAvailable ProvisioningState = "available"
+
 	// StateProvisioning means we are writing an image to the host's
 	// disk(s)
 	StateProvisioning ProvisioningState = "provisioning"
@@ -175,6 +182,10 @@ type BareMetalHostSpec struct {
 	// data to be passed to the host before it boots.
 	UserData *corev1.SecretReference `json:"userData,omitempty"`
 
+	// NetworkData holds the reference to the Secret containing content
+	// of network_data.json which is passed to Config Drive
+	NetworkData *corev1.SecretReference `json:"networkData,omitempty"`
+
 	// Description is a human-entered text used to help identify the host
 	Description string `json:"description,omitempty"`
 
@@ -699,7 +710,7 @@ func (host *BareMetalHost) NewEvent(reason, message string) corev1.Event {
 			Namespace:  host.Namespace,
 			Name:       host.Name,
 			UID:        host.UID,
-			APIVersion: SchemeGroupVersion.Version,
+			APIVersion: SchemeGroupVersion.String(),
 		},
 		Reason:  reason,
 		Message: message,
